import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.4952fe91.js";import{B as y}from"./BaseLayout.b766196f.js";import{d as l,a6 as m,bY as b,Q as u,aT as v,aU as g,o as _,K as h,a as r,N as s,e4 as w,e3 as S,J as k,c as L,w as n,b as i,u as x}from"./index.b7bd503f.js";import{u as B}from"./editor.1ed1c30b.js";import{b as I}from"./index.5b720ad7.js";import"./Logo.15abdca4.js";import"./userStore.aae0ee54.js";import"./workspaceStore.48f36fba.js";import"./runnerData.b90a4871.js";import"./url.c0ede6d9.js";import"./colorHelpers.60b3e5dc.js";import"./linters.a9c213b8.js";import"./asyncComputed.d7c4e941.js";import"./index.ba206f89.js";import"./Avatar.8a8cac11.js";import"./index.173038d0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="3488af3e-cc07-4608-bc42-2907aa61649a",e._sentryDebugIdIdentifier="sentry-dbid-3488af3e-cc07-4608-bc42-2907aa61649a")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=m({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(o)}}});const P={class:"v-spinner"};function D(e,o,a,c,d,p){return v((_(),h("div",P,[r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u($,[["render",D],["__scopeId","data-v-06538001"]]),R={class:"content"},j=l({__name:"ProjectLogin",setup(e){const o=w(),a=S(),c=B();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function p(){const t=o.query["api-key"];if(typeof t=="string")return t}return k(async()=>{const t=p();if(!t){a.push({name:"error"});return}await c.createLogin(t).then(d),a.push({name:"workspace"})}),(t,z)=>(_(),L(y,null,{navbar:n(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[r("div",R,[i(K)])]),_:1}))}});const W=u(j,[["__scopeId","data-v-944edebb"]]);export{W as default};
//# sourceMappingURL=ProjectLogin.b2b192b5.js.map
