import{C as t,E as i,K as d,a as f,M as c,c as l,P as y,R as b,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.d8e8df4b.js";import"./index.b7bd503f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cb6619ee-8007-4f94-8370-4352802ef107",e._sentryDebugIdIdentifier="sentry-dbid-cb6619ee-8007-4f94-8370-4352802ef107")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,f as KeyMod,c as MarkerSeverity,l as MarkerTag,y as Position,b as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.096287b1.js.map
