import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.a65eada5.js";import{R as f}from"./tasksController.eafb8cd5.js";import{d as b,e4 as _,g,K as y,b as w,w as k,u as n,c as I,F as T,aL as v,o as l,az as B,d6 as j}from"./index.b7bd503f.js";import"./gateway.6db311e2.js";import{a as x,B as C}from"./build.1800d9f9.js";import{P as D}from"./project.1a8e28e5.js";import"./columns.c99cb402.js";import{a as R}from"./asyncComputed.d7c4e941.js";import"./metadata.a520978c.js";import"./PhWebhooksLogo.vue.3d766f96.js";import"./ant-design.9ec9316b.js";import"./string.9a3a939b.js";import"./index.78ee4489.js";import"./dayjs.9e6acd5c.js";import"./linters.a9c213b8.js";import"./scripts.07d85532.js";import"./record.c86f39d9.js";import"./polling.29467055.js";import"./popupNotifcation.bbf38424.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="efa91c9b-368f-4256-a79f-0c42bdf8a285",e._sentryDebugIdIdentifier="sentry-dbid-efa91c9b-368f-4256-a79f-0c42bdf8a285")}catch{}})();const U=b({__name:"Tasks",setup(e){const a=_().params.projectId,p=new f(a),{result:o}=R(async()=>{const r=(await x.list(a)).find(d=>d.latest);if(!r)return null;const[u,c]=await Promise.all([C.get(r.id),D.get(a)]);return{buildSpec:u,project:c}}),i=g(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(l(),y(v,null,[w(n(j),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(l(),I(m,{key:0,class:"tasks",api:n(p),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.72eda07d.js.map
