import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.4d2fd56c.js";import{d as m,e3 as f,e4 as g,K as y,b,u as n,o as w,Q as k}from"./index.b7bd503f.js";import{u as h}from"./workspaceStore.48f36fba.js";import"./userStore.aae0ee54.js";import"./CircularLoading.8ce20df9.js";import"./Logo.15abdca4.js";import"./string.9a3a939b.js";import"./index.6e3cf911.js";import"./runnerData.b90a4871.js";import"./url.c0ede6d9.js";import"./colorHelpers.60b3e5dc.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6ae5672e-8580-4c6f-a254-6621425c6591",e._sentryDebugIdIdentifier="sentry-dbid-6ae5672e-8580-4c6f-a254-6621425c6591")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),t=g(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,p,u,i,d;return w(),y("div",v,[b(l,{"logo-url":(p=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?p:void 0,"brand-name":(u=n(r).state.workspace)==null?void 0:u.brandName,locale:(d=(i=n(r).state.workspace)==null?void 0:i.language)!=null?d:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const K=k(I,[["__scopeId","data-v-cb33c596"]]);export{K as default};
//# sourceMappingURL=Login.aa83583b.js.map
