import{O as s,R as a}from"./OmniChat.19b09370.js";import{d as c,e4 as d,o as i,c as p,u as n}from"./index.b7bd503f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="376c456a-469d-44fe-99b5-a84b92c42d6d",e._sentryDebugIdIdentifier="sentry-dbid-376c456a-469d-44fe-99b5-a84b92c42d6d")}catch{}})();const _=c({__name:"ConsoleOmniChat",setup(e){const t=d().params.projectId,r=new a(t);return(u,f)=>(i(),p(s,{"ai-chat-repository":n(r),environment:{origin:"console",projectId:n(t)}},null,8,["ai-chat-repository","environment"]))}});export{_};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.d9597351.js.map
