import{C as p}from"./controller.9c04467d.js";import{d as i,e4 as n,c as s,u as m,o as a}from"./index.b7bd503f.js";import{_ as d}from"./View.vue_vue_type_script_setup_true_lang.0f6f5dd2.js";import"./gateway.6db311e2.js";import"./popupNotifcation.bbf38424.js";import"./fetch.2ad11096.js";import"./record.c86f39d9.js";import"./PhPencil.vue.6d6dc1ad.js";import"./SaveButton.fc33b162.js";import"./UnsavedChangesHandler.d36340f1.js";import"./ExclamationCircleOutlined.d04c3f35.js";import"./CrudView.c9a70a38.js";import"./router.7c58172b.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.a6841fb4.js";import"./url.c0ede6d9.js";import"./PhDotsThreeVertical.vue.5c0a03a4.js";import"./Badge.53ab4d2d.js";import"./index.173038d0.js";import"./index.78ee4489.js";import"./asyncComputed.d7c4e941.js";import"./polling.29467055.js";import"./omniChatStore.0918de26.js";import"./index.6e3cf911.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="0d5d355c-00e6-4823-a80d-22e6cf7bcf39",o._sentryDebugIdIdentifier="sentry-dbid-0d5d355c-00e6-4823-a80d-22e6cf7bcf39")}catch{}})();const F=i({__name:"EnvVars",setup(o){const e=n().params.projectId,t=new p(e);return(c,f)=>(a(),s(d,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{F as default};
//# sourceMappingURL=EnvVars.890f04e0.js.map
