import{d as a,o,K as s,b as d,u as r,br as _,Q as c}from"./index.b7bd503f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="01268fdd-42e2-427c-871b-a549a03eebb8",e._sentryDebugIdIdentifier="sentry-dbid-01268fdd-42e2-427c-871b-a549a03eebb8")}catch{}})();const i={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[d(r(_))]))}});const p=c(f,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.8929aa5b.js.map
