import{_ as b}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.4952fe91.js";import{C as h}from"./ContentLayout.4be61bce.js";import{l as k}from"./fetch.2ad11096.js";import{d as w,e3 as g,e4 as v,f as C,c,w as s,o as i,b as f,a as x,u as d,d2 as _,az as m,Q as I}from"./index.b7bd503f.js";import{u as T,E as D}from"./editor.1ed1c30b.js";import{C as L}from"./Card.611b7fe6.js";import"./Logo.15abdca4.js";import"./userStore.aae0ee54.js";import"./workspaceStore.48f36fba.js";import"./runnerData.b90a4871.js";import"./url.c0ede6d9.js";import"./colorHelpers.60b3e5dc.js";import"./linters.a9c213b8.js";import"./asyncComputed.d7c4e941.js";import"./TabPane.3b3150c6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="05b59859-61a1-4b5f-9d3c-89c38b606ca3",e._sentryDebugIdIdentifier="sentry-dbid-05b59859-61a1-4b5f-9d3c-89c38b606ca3")}catch{}})();const N={class:"card-content"},j=w({__name:"Welcome",setup(e){const t=g(),{query:n}=v(),a=T();a.loadLogin();const l=C(!0),u=async()=>{l.value=!1,setInterval(()=>{var o;return window.location.replace(((o=a==null?void 0:a.links)==null?void 0:o.project)||D.consoleUrl)},5e3)};return(async()=>{const o=n.token,r=n.redirect,p=await k("/_editor/auth/set-cookie",{method:"POST",body:JSON.stringify({token:o}),headers:{"Content-Type":"application/json"}});if(!p.ok)return u();const{ok:y}=await p.json();if(!y)return u();r?await t.push({path:r}):await t.push({name:"workspace"})})(),(o,r)=>(i(),c(h,null,{default:s(()=>[f(d(L),{bordered:!1,class:"card"},{default:s(()=>[x("div",N,[f(b,{style:{"margin-bottom":"10px"}}),l.value?(i(),c(d(_),{key:0},{default:s(()=>[m("Loading...")]),_:1})):(i(),c(d(_),{key:1},{default:s(()=>[m("Authentication failed. You are been redirected...")]),_:1}))])]),_:1})]),_:1}))}});const $=I(j,[["__scopeId","data-v-ba310460"]]);export{$ as default};
//# sourceMappingURL=Welcome.04ca617d.js.map
