import{G as s,dv as i,dw as d}from"./index.b7bd503f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="44c47afc-0d05-42c6-8c4e-9acaf7be03a4",e._sentryDebugIdIdentifier="sentry-dbid-44c47afc-0d05-42c6-8c4e-9acaf7be03a4")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:a,YearPicker:f,TimePicker:m,QuarterPicker:c,RangePicker:r}=i(d),y=s(n,{WeekPicker:t,MonthPicker:a,YearPicker:f,RangePicker:r,TimePicker:m,QuarterPicker:c,install:e=>(e.component(n.name,n),e.component(r.name,r),e.component(a.name,a),e.component(t.name,t),e.component(c.name,c),e)});export{y as D,a as M,c as Q,r as R,t as W};
//# sourceMappingURL=dayjs.9e6acd5c.js.map
