import{P as f}from"./PlayerNavbar.96bd45f2.js";import{d as g,e3 as h,e4 as c,f as y,g as b,r as k,K as v,u as n,c as w,F as L,a as C,b as I,o as i,Q as N}from"./index.b7bd503f.js";import{u as V}from"./workspaceStore.48f36fba.js";import"./userStore.aae0ee54.js";import"./metadata.a520978c.js";import"./PhWebhooksLogo.vue.3d766f96.js";import"./LoadingOutlined.f388ee57.js";import"./PhSignOut.vue.84503c82.js";import"./index.ba206f89.js";import"./Avatar.8a8cac11.js";import"./runnerData.b90a4871.js";import"./url.c0ede6d9.js";import"./colorHelpers.60b3e5dc.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="42a387f2-2ac6-4c80-b7a8-5216b6696762",o._sentryDebugIdIdentifier="sentry-dbid-42a387f2-2ac6-4c80-b7a8-5216b6696762")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=c().path,a=y(null),p=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},d=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return i(),v("div",x,[n(t).state.workspace?(i(),w(f,{key:0,"current-path":n(u),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:p,onLoginClick:l,onLogoutClick:d},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.a4092669.js.map
