import{m as a,n,T as r,p as o,P as p,C as d,M as c,s as f,q as s,t as m,v as u,x as g,y}from"./index.b7bd503f.js";import{s as b}from"./userStore.aae0ee54.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.203b9810.js";import{a as i}from"./workspaceStore.48f36fba.js";import"./PlayerConfigProvider.81e57d39.js";import"./colorHelpers.60b3e5dc.js";import"./index.1a435717.js";import"./runnerData.b90a4871.js";import"./url.c0ede6d9.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="e7493fe5-71f6-4bec-aae3-59cdeacb4750",t._sentryDebugIdIdentifier="sentry-dbid-e7493fe5-71f6-4bec-aae3-59cdeacb4750")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const t=a(),e=n({render:()=>m(l)});r.init(),o(e,i),w.init(),e.use(i),e.use(t),e.use(p),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",c),e.component("Message",f),s(e,u),s(e,g),s(e,y)})();
//# sourceMappingURL=player.5bb67275.js.map
