import{b as l,e6 as o,eG as f}from"./index.b7bd503f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d2d06de4-4818-4508-a409-46a7ac7ddaff",e._sentryDebugIdIdentifier="sentry-dbid-d2d06de4-4818-4508-a409-46a7ac7ddaff")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(a){return Object.getOwnPropertyDescriptor(r,a).enumerable}))),n.forEach(function(a){u(e,a,r[a])})}return e}function u(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var d=function(t,r){var n=i({},t,r.attrs);return l(o,i({},n,{icon:f}),null)};d.displayName="CloseCircleOutlined";d.inheritAttrs=!1;const s=d;export{s as C};
//# sourceMappingURL=CloseCircleOutlined.91236e5b.js.map
