import{d as i,c as p,w as n,o as m,b as d,u as t}from"./index.b7bd503f.js";import"./linters.a9c213b8.js";import{W as s}from"./workspaces.3874dfe4.js";import{C as a}from"./ContentLayout.4be61bce.js";import{E as f}from"./controller.9c04467d.js";import{_ as c}from"./View.vue_vue_type_script_setup_true_lang.0f6f5dd2.js";import"./asyncComputed.d7c4e941.js";import"./runnerData.b90a4871.js";import"./url.c0ede6d9.js";import"./colorHelpers.60b3e5dc.js";import"./record.c86f39d9.js";import"./gateway.6db311e2.js";import"./popupNotifcation.bbf38424.js";import"./fetch.2ad11096.js";import"./PhPencil.vue.6d6dc1ad.js";import"./SaveButton.fc33b162.js";import"./UnsavedChangesHandler.d36340f1.js";import"./ExclamationCircleOutlined.d04c3f35.js";import"./CrudView.c9a70a38.js";import"./router.7c58172b.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.a6841fb4.js";import"./PhDotsThreeVertical.vue.5c0a03a4.js";import"./Badge.53ab4d2d.js";import"./index.173038d0.js";import"./index.78ee4489.js";import"./polling.29467055.js";import"./omniChatStore.0918de26.js";import"./index.6e3cf911.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="d12e8d04-87c1-4d9b-b1bc-68d1a49f0c59",o._sentryDebugIdIdentifier="sentry-dbid-d12e8d04-87c1-4d9b-b1bc-68d1a49f0c59")}catch{}})();const H=i({__name:"EnvVarsEditor",setup(o){const r=new f;return(e,u)=>(m(),p(a,null,{default:n(()=>[d(c,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{H as default};
//# sourceMappingURL=EnvVarsEditor.36e2dd2d.js.map
