import{_ as k}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.4952fe91.js";import{d as v,e4 as A,e3 as x,g as h,K as I,b as c,w as a,u as e,c as p,F as m,o as i,az as s,eb as l,d6 as C,d2 as f,bM as N,a as B,d3 as D,eh as o,Q as T}from"./index.b7bd503f.js";import{u as E}from"./workspaceStore.48f36fba.js";import{C as V}from"./Card.611b7fe6.js";import"./Logo.15abdca4.js";import"./userStore.aae0ee54.js";import"./runnerData.b90a4871.js";import"./url.c0ede6d9.js";import"./colorHelpers.60b3e5dc.js";import"./TabPane.3b3150c6.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new $().stack;d&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[d]="358a0092-ceb4-4049-a6c1-b74d07439e56",r._sentryDebugIdIdentifier="sentry-dbid-358a0092-ceb4-4049-a6c1-b74d07439e56")}catch{}})();const S={class:"inner-content"},H={class:"card-content"},R=v({__name:"Error",setup(r){const d=A(),g=x(),u=E(),b=h(()=>{var t,_,y;return(y=(t=u.state.workspace)==null?void 0:t.name)!=null?y:(_=u.state.workspace)==null?void 0:_.brandName}),n=h(()=>{const{status:t}=d.params;switch(t){case"404":return{status:t,title:o.translate("i18n_page_not_found"),message:o.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:t,title:o.translate("i18n_access_denied"),message:o.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:o.translate("i18n_internal_error"),message:o.translate("i18n_internal_error_message"),showAd:!1}}}),w=()=>{g.push({name:"playerHome"})};return(t,_)=>(i(),I("div",S,[c(e(C),null,{default:a(()=>[s(l(n.value.title),1)]),_:1}),c(e(f),{class:"message"},{default:a(()=>[s(l(n.value.message),1)]),_:1}),n.value.action?(i(),p(e(N),{key:0,type:"link",onClick:w},{default:a(()=>[s(l(n.value.action),1)]),_:1})):m("",!0),n.value.showAd?(i(),p(e(V),{key:1,bordered:!1,class:"card"},{default:a(()=>[B("div",H,[c(k,{style:{"margin-bottom":"10px"}}),c(e(f),null,{default:a(()=>[s("This page is part of "+l(b.value?`the ${b.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(u).state.workspace?(i(),p(e(f),{key:0},{default:a(()=>[s("Automate your own processes by getting started "),c(e(D),{href:"https://abstra.io"},{default:a(()=>[s("here")]),_:1}),s(".")]),_:1})):m("",!0)])]),_:1})):m("",!0)]))}});const $=T(R,[["__scopeId","data-v-f16a0b67"]]);export{$ as default};
//# sourceMappingURL=Error.861e629b.js.map
