import{C as r}from"./gateway.6db311e2.js";import"./index.b7bd503f.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="0ece8df7-e4a2-4072-9eea-0a6abad1fb21",n._sentryDebugIdIdentifier="sentry-dbid-0ece8df7-e4a2-4072-9eea-0a6abad1fb21")}catch{}})();class s{async list(e){return r.get(`organizations/${e}/folders`)}async create(e){return r.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async delete(e,a){return r.delete(`organizations/${e}/folders/${a}`)}async update(e,a){return r.patch(`organizations/${e}/folders/${a.id}/`,{name:a.name,memberIds:a.memberIds})}}export{s as F};
//# sourceMappingURL=folder.c0c09ebb.js.map
