import{P as r}from"./record.c86f39d9.js";import{e as c,f as a}from"./index.b7bd503f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="886c10ea-5764-4942-a4fc-d7c147340605",e._sentryDebugIdIdentifier="sentry-dbid-886c10ea-5764-4942-a4fc-d7c147340605")}catch{}})();const i=new r,b=c("omniChat",()=>{const e=a(!1),t=a(!1),n=()=>{t.value=!0},s=()=>{t.value=!1},o=()=>{e.value=!0,n()},u=()=>{e.value=!1,s()};return{isOpen:e,isInputFocused:t,focusInput:n,blurInput:s,open:o,close:u,toggle:()=>{e.value?u():o()}}});export{i as o,b as u};
//# sourceMappingURL=omniChatStore.0918de26.js.map
