import{i as k}from"./metadata.a520978c.js";import{W as h}from"./Watermark.f6ca7f94.js";import{F as b}from"./PhArrowSquareOut.vue.aca0545c.js";import{d as w,e3 as v,g as x,f as C,u as e,K as m,b as p,w as r,F as z,o as t,c as n,az as f,d2 as y,aL as D,ea as I,da as _,ei as F,eb as L,ec as T,Q as B}from"./index.b7bd503f.js";import{u as H}from"./workspaceStore.48f36fba.js";import"./index.b783f91b.js";import{L as N}from"./LoadingOutlined.f388ee57.js";import{C as S}from"./Card.611b7fe6.js";import"./PhWebhooksLogo.vue.3d766f96.js";import"./userStore.aae0ee54.js";import"./runnerData.b90a4871.js";import"./url.c0ede6d9.js";import"./colorHelpers.60b3e5dc.js";import"./TabPane.3b3150c6.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="53d45487-3502-4f91-8b7a-0aa867dd0aeb",o._sentryDebugIdIdentifier="sentry-dbid-53d45487-3502-4f91-8b7a-0aa867dd0aeb")}catch{}})();const V={key:0,class:"home-container"},W=w({__name:"Home",setup(o){const i=v(),l=H(),u=x(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(c=>c.id!=="home"))||[]}),d=C(null),g=async(s,c)=>{d.value=c,await i.push({path:`/${s}`}),d.value=null};return(s,c)=>e(l).state.workspace?(t(),m("div",V,[p(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(t(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(" There are no forms available for you. ")]),_:1})):(t(!0),m(D,{key:1},I(u.value,a=>(t(),n(e(S),{key:a.id,class:T(["form-card",{loading:d.value===a.id}]),"body-style":{cursor:"pointer"},onClick:E=>g(a.path,a.id)},{default:r(()=>[p(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(t(),n(F(e(k)(a.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(L(a.name),1)]),_:2},1024),d.value!==a.id?(t(),n(e(b),{key:0,size:"20"})):(t(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(h,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):z("",!0)}});const Y=B(W,[["__scopeId","data-v-060376d1"]]);export{Y as default};
//# sourceMappingURL=Home.86571608.js.map
