import{_ as f}from"./TasksView.vue_vue_type_script_setup_true_lang.a65eada5.js";import{L as p}from"./tasksController.eafb8cd5.js";import{d,f as u,c as _,w as t,o as m,b as s,u as o,d6 as y,az as i,bM as k,da as b,Q as w}from"./index.b7bd503f.js";import{C as g}from"./ContentLayout.4be61bce.js";import{a as T}from"./ant-design.9ec9316b.js";import"./metadata.a520978c.js";import"./PhWebhooksLogo.vue.3d766f96.js";import"./string.9a3a939b.js";import"./index.78ee4489.js";import"./dayjs.9e6acd5c.js";import"./gateway.6db311e2.js";import"./popupNotifcation.bbf38424.js";import"./linters.a9c213b8.js";import"./asyncComputed.d7c4e941.js";import"./scripts.07d85532.js";import"./record.c86f39d9.js";import"./polling.29467055.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="833b5386-f1ac-4463-8d12-3160f26e245e",e._sentryDebugIdIdentifier="sentry-dbid-833b5386-f1ac-4463-8d12-3160f26e245e")}catch{}})();const x=d({__name:"Tasks",setup(e){const a=new p,r=u(null);async function l(){var n;await T("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(c,n)=>(m(),_(g,null,{default:t(()=>[s(o(b),{justify:"space-between",align:"center"},{default:t(()=>[s(o(y),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(k),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(f,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const $=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{$ as default};
//# sourceMappingURL=Tasks.ee5cffa3.js.map
