import{i as A}from"./url.c0ede6d9.js";import"./index.b7bd503f.js";import{i as L}from"./colorHelpers.60b3e5dc.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="8878d3c5-2fd5-43e5-a91b-c08a5d8db64e",e._sentryDebugIdIdentifier="sentry-dbid-8878d3c5-2fd5-43e5-a91b-c08a5d8db64e")}catch{}})();function w(e,a,s){return A(a)?a:s==="player"?`/_assets/${e}`:`/_editor/api/assets/${a}`}const F="#414a58",y="#FFFFFF",E="#000000",D="DM Sans",O="Untitled Project",T={value:"en",label:"English"};function U(e){var a,s,r,n,t,l,o,i,u,_,c,m,f,g,b,p;return{id:e.id,path:e.path,theme:(a=e.workspace.theme)!=null?a:y,brandName:(s=e.workspace.brand_name)!=null?s:null,title:e.title,isInitial:e.is_initial,isLocal:(r=e.is_local)!=null?r:!1,startMessage:(n=e.start_message)!=null?n:null,endMessage:(t=e.end_message)!=null?t:null,errorMessage:(l=e.error_message)!=null?l:null,timeoutMessage:(o=e.timeout_message)!=null?o:null,startButtonText:(i=e.start_button_text)!=null?i:null,restartButtonText:(u=e.restart_button_text)!=null?u:null,logoUrl:e.workspace.logo_url,mainColor:(_=e.workspace.main_color)!=null?_:F,fontFamily:(c=e.workspace.font_family)!=null?c:D,autoStart:(m=e.auto_start)!=null?m:!1,allowRestart:e.allow_restart,welcomeTitle:(f=e.welcome_title)!=null?f:null,runtimeType:"form",language:(g=e.workspace.language)!=null?g:T.value,sidebar:(p=(b=e.workspace)==null?void 0:b.sidebar)!=null?p:[]}}function d(e){var s;const a=(s=e.theme)!=null?s:y;return{name:e.name||O,fontColor:e.font_color||E,sidebar:e.sidebar||[],brandName:e.brand_name||"",fontFamily:e.font_family||D,logoUrl:e.logo_url?w("logo",e.logo_url,"player"):null,mainColor:e.main_color||F,theme:L(a)?a:w("background",a,"player"),language:e.language||T.value}}export{F as D,D as a,T as b,y as c,w as m,U as r,d as w};
//# sourceMappingURL=runnerData.b90a4871.js.map
