import{d as i,eo as d,g as r,o as a,K as t,F as c,ec as g,eb as p,Q as u}from"./index.b7bd503f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="1ec2eb29-5991-4e08-98cb-c3f26b171ae2",e._sentryDebugIdIdentifier="sentry-dbid-1ec2eb29-5991-4e08-98cb-c3f26b171ae2")}catch{}})();const _={class:"logo"},f=["src","alt"],m=i({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;d(o=>({"4521d904":n.value}));const n=r(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),l=r(()=>`${s.brandName} Logo`);return(o,b)=>(a(),t("div",_,[o.imageUrl?(a(),t("img",{key:0,class:"logo-img",src:o.imageUrl,alt:l.value},null,8,f)):c("",!0),o.hideText?c("",!0):(a(),t("span",{key:1,class:g(o.size)},p(o.brandName),3))]))}});const h=u(m,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.15abdca4.js.map
