import{d as n,K as s,a,O as d,ec as r,o as l,Q as _}from"./index.b7bd503f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="e58edb86-f399-4e92-a083-0ad42e5f03f6",e._sentryDebugIdIdentifier="sentry-dbid-e58edb86-f399-4e92-a083-0ad42e5f03f6")}catch{}})();const f={class:"content-layout"},u=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(l(),s("div",f,[a("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[d(t.$slots,"default",{},void 0,!0)],2)]))}});const i=_(u,[["__scopeId","data-v-6397d501"]]);export{i as C};
//# sourceMappingURL=ContentLayout.4be61bce.js.map
