import{B as m}from"./BaseLayout.b766196f.js";import{d as a,e4 as n,r as s,c,w as r,o as d,b as i,u as f}from"./index.b7bd503f.js";import{N as u,_}from"./Navbar.143b4234.js";import"./OmniChat.19b09370.js";import"./gateway.6db311e2.js";import"./popupNotifcation.bbf38424.js";import"./AbstraLogo.vue_vue_type_script_setup_true_lang.4952fe91.js";import"./Logo.15abdca4.js";import"./uuid.73310edf.js";import"./PhClockCounterClockwise.vue.7bf46397.js";import"./omniChatStore.0918de26.js";import"./record.c86f39d9.js";import"./LoadingOutlined.f388ee57.js";import"./columns.c99cb402.js";import"./string.9a3a939b.js";import"./linters.a9c213b8.js";import"./asyncComputed.d7c4e941.js";import"./controller.8f5d17b3.js";import"./workspaces.3874dfe4.js";import"./runnerData.b90a4871.js";import"./url.c0ede6d9.js";import"./colorHelpers.60b3e5dc.js";import"./index.03907aa7.js";import"./validations.5b707456.js";import"./metadata.a520978c.js";import"./PhWebhooksLogo.vue.3d766f96.js";import"./controller.9c04467d.js";import"./fetch.2ad11096.js";import"./PhPencil.vue.6d6dc1ad.js";import"./project.1a8e28e5.js";import"./requirements.e2fc57f0.js";import"./object.f878dd27.js";import"./scripts.07d85532.js";import"./PhCopySimple.vue.9da27544.js";import"./index.0321b4ad.js";import"./CollapsePanel.03665596.js";import"./Avatar.8a8cac11.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang.bef4d8ba.js";import"./PhArrowCounterClockwise.vue.9f00e482.js";import"./PhFilePy.vue.4e7247f2.js";import"./PhChats.vue.7f69aca3.js";import"./PhRocket.vue.0b1ccce5.js";import"./PhPackage.vue.c804c6f5.js";import"./userStore.aae0ee54.js";import"./polling.29467055.js";import"./PhArrowSquareOut.vue.aca0545c.js";import"./PhDotsThree.vue.7a9da04b.js";import"./PhSignOut.vue.84503c82.js";import"./PhSparkle.vue.d0b7c741.js";import"./editor.1ed1c30b.js";import"./workspaceStore.48f36fba.js";import"./index.173038d0.js";import"./CloseCircleOutlined.91236e5b.js";import"./CheckCircleFilled.ccc9e063.js";import"./index.6e3cf911.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="7fa3327b-b33e-47be-9ddf-2a09491e39c0",t._sentryDebugIdIdentifier="sentry-dbid-7fa3327b-b33e-47be-9ddf-2a09491e39c0")}catch{}})();const yt=a({__name:"Workspace",setup(t){const o=n();return(p,l)=>{const e=s("RouterView");return d(),c(m,null,{navbar:r(()=>[i(u,{"page-title":f(o).meta.title},null,8,["page-title"])]),content:r(()=>[i(e)]),chat:r(()=>[i(_)]),_:1})}}});export{yt as default};
//# sourceMappingURL=Workspace.e662d71e.js.map
