import{C as o}from"./Card.611b7fe6.js";import{d as p,a9 as g,bO as d,b as r,by as i,g as D}from"./index.b7bd503f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="dcb79825-5cd8-439b-9b98-407ac849d0a9",e._sentryDebugIdIdentifier="sentry-dbid-dcb79825-5cd8-439b-9b98-407ac849d0a9")}catch{}})();const _=()=>({prefixCls:String,title:i(),description:i(),avatar:i()}),c=p({compatConfig:{MODE:3},name:"ACardMeta",props:_(),slots:Object,setup(e,n){let{slots:a}=n;const{prefixCls:t}=g("card",e);return()=>{const l={[`${t.value}-meta`]:!0},s=d(a,e,"avatar"),v=d(a,e,"title"),m=d(a,e,"description"),C=s?r("div",{class:`${t.value}-meta-avatar`},[s]):null,f=v?r("div",{class:`${t.value}-meta-title`},[v]):null,b=m?r("div",{class:`${t.value}-meta-description`},[m]):null,y=f||b?r("div",{class:`${t.value}-meta-detail`},[f,b]):null;return r("div",{class:l},[C,y])}}}),M=()=>({prefixCls:String,hoverable:{type:Boolean,default:!0}}),u=p({compatConfig:{MODE:3},name:"ACardGrid",__ANT_CARD_GRID:!0,props:M(),setup(e,n){let{slots:a}=n;const{prefixCls:t}=g("card",e),l=D(()=>({[`${t.value}-grid`]:!0,[`${t.value}-grid-hoverable`]:e.hoverable}));return()=>{var s;return r("div",{class:l.value},[(s=a.default)===null||s===void 0?void 0:s.call(a)])}}});o.Meta=c;o.Grid=u;o.install=function(e){return e.component(o.name,o),e.component(c.name,c),e.component(u.name,u),e};export{u as G,c as M};
//# sourceMappingURL=index.b783f91b.js.map
