import{d as c,g as b,o as r,c as d,w as o,b as l,u as n,da as i,O as p,F as u,ep as y,eq as g,bM as f,aP as m,e5 as _}from"./index.b7bd503f.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="13b5860a-5ab6-4d73-8d68-ea5c21a8e21a",t._sentryDebugIdIdentifier="sentry-dbid-13b5860a-5ab6-4d73-8d68-ea5c21a8e21a")}catch{}})();const w=c({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(t){const e=t,s=b(()=>e.disabledTooltip&&e.disabled?e.disabledTooltip:e.tooltip);return(a,k)=>s.value?(r(),d(n(m),{key:0,title:s.value},{default:o(()=>[l(n(f),y(g(a.$props)),{default:o(()=>[l(n(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:o(()=>[a.loading?u("",!0):p(a.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"])):(r(),d(n(f),y(_({key:1},a.$props)),{default:o(()=>[l(n(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:o(()=>[a.loading?u("",!0):p(a.$slots,"default",{key:0})]),_:3})]),_:3},16))}});export{w as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.bef4d8ba.js.map
