import{O as r}from"./userStore.aae0ee54.js";import{d as l,J as u,K as i,b as a,w as n,u as o,o as c,az as d,d6 as f,d5 as b}from"./index.b7bd503f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a89c9b0d-af65-44d1-b983-7b7fd97a409c",e._sentryDebugIdIdentifier="sentry-dbid-a89c9b0d-af65-44d1-b983-7b7fd97a409c")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new r().logoutCallback()}),(t,s)=>(c(),i("div",null,[a(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback.81da4e6f.js.map
