import{L as n}from"./Logo.15abdca4.js";import{d as r,o as a,c as d,u as i}from"./index.b7bd503f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="e353be80-c9e5-42cc-9c9b-c2434eb5f385",e._sentryDebugIdIdentifier="sentry-dbid-e353be80-c9e5-42cc-9c9b-c2434eb5f385")}catch{}})();const c="/assets/logo.0faadfa2.svg",l=r({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,t)=>{var o;return a(),d(n,{"image-url":i(c),"brand-name":"Abstra","hide-text":s.hideText,size:(o=s.size)!=null?o:"small"},null,8,["image-url","hide-text","size"])}}});export{l as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.4952fe91.js.map
